@@ -72,11 +72,11 @@ def get_progress_bar(bartype="text", title=""):
             pbar = ClProgressDialog()
             pbar.setCancelButton(None)
             pbar.adjustSize()
-            pbar.setWindowTitle(title.decode('utf-8'))
+            pbar.setWindowTitle(title)
             pbar.setAutoClose(False)
             pbar.setAutoReset(False)
             pbar.setMaximum(0)
-            pbar.setLabelText(title.decode('utf-8'))
+            pbar.setLabelText(title)
             pbar.setTextVisible(False)
             pbar.setStyleSheet("QProgressBar {border:none; text-align: center;}")
             return pbar
