@@ -120,5 +120,4 @@ class kernel(TemplateFormat):
                 return '%s=%s\n' % (key, value)
 
         return "".join([getline(key, value)
-                        for key, value in self.doc.body.items()]).decode(
-            'UTF-8')
+                        for key, value in self.doc.body.items()])
